@@ -6,7 +6,7 @@ import re
 #import time
 from datetime import datetime, timedelta
 #import jieba.posseg as psg
-import utils
+import query_toolkits.utils as utils
 
 
 class Extractor:
